/*en    Laurent Constantin's network library (lcrzo)
                 lcrzo_winhandle module

  Functions herein allow to read/write from Windows' HANDLE.
*/
/*fr    Bibliotheque reseau de Laurent Constantin (lcrzo)
                 Module lcrzo_winhandle

  Les fonctions presentes dans ce module assurent la gestion
des HANDLE Windows.
*/

/*-------------------------------------------------------------*/
/*en definition of a lcrzo_winhandle. You should not use its
   fields directly. */
/*fr definition d'un lcrzo_winhandle. Vous ne devriez pas utiliser
   directement ses champs. */
typedef struct
{ LCRZOHANDLE thehandle;
  lcrzo_bool openforreading;
  lcrzo_bool openforwriting;
  lcrzo_bool dataend;
  lcrzo_int16 type;
  lcrzo_data storeddata;
  lcrzo_int32 storeddatasize;
} lcrzo_winhandle;


/*-------------------------------------------------------------*/
/*en Name : lcrzo_winhandle_init_handle
   Description :
     Associate a lcrzo_winhandle to a HANDLE.
     After this function, user has to close the HANDLE and pwinhandle.
   Input parameter(s) :
     thehandle : HANDLE
   Input/output parameter(s) :
   Output parameter(s) :
     *pwinhandle : lcrzo_winhandle which is associated to fd
   Normal return values :
     LCRZO_ERR_OK : ok
*/
/*fr Nom : lcrzo_winhandle_init_handle
   Description :
     Associe un lcrzo_winhandle a un HANDLE.
     Apres cette fonction, l'utilisateur devra fermer le HANDLE et
     pwinhandle.
   Parametre(s) d'entree :
     thehandle : HANDLE
   Parametre(s) d'entree-sortie :
   Parametre(s) de sortie :
     *pwinhandle : lcrzo_winhandle qui est associe a fd
   Valeurs de retour normales :
     LCRZO_ERR_OK : ok
*/
int lcrzo_winhandle_init_handle(LCRZOHANDLE thehandle,
                      lcrzo_winhandle *pwinhandle);

/*-------------------------------------------------------------*/
/*en Name : lcrzo_winhandle_close
   Description :
     Close a lcrzo_winhandle.
   Input parameter(s) :
     pwinhandle : lcrzo_winhandle to close
   Input/output parameter(s) :
   Output parameter(s) :
   Normal return values :
     LCRZO_ERR_OK : ok
*/
/*fr Nom : lcrzo_winhandle_close
   Description :
     Ferme un lcrzo_winhandle.
   Parametre(s) d'entree :
     pwinhandle : lcrzo_winhandle a fermer
   Parametre(s) d'entree-sortie :
   Parametre(s) de sortie :
   Valeurs de retour normales :
     LCRZO_ERR_OK : ok
*/
int lcrzo_winhandle_close(lcrzo_winhandle *pwinhandle);

/*-------------------------------------------------------------*/
/*en Name : lcrzo_handle_init_winhandle
   Description :
     Obtain the HANDLE associated to a lcrzo_winhandle.
   Input parameter(s) :
     *pwinhandle : lcrzo_winhandle
   Input/output parameter(s) :
   Output parameter(s) :
     *phandle : HANDLE associated to pwinhandle
   Normal return values :
     LCRZO_ERR_OK : ok
*/
/*fr Nom : lcrzo_handle_init_winhandle
   Description :
     Obtient le HANDLE associe a un lcrzo_winhandle.
   Parametre(s) d'entree :
     *pwinhandle : lcrzo_winhandle
   Parametre(s) d'entree-sortie :
   Parametre(s) de sortie :
     *phandle : HANDLE associe a pwinhandle
   Valeurs de retour normales :
     LCRZO_ERR_OK : ok
*/
int lcrzo_handle_init_winhandle(lcrzo_winhandle *pwinhandle, 
                        LCRZOHANDLE *phandle);


/*-------------------------------------------------------------*/
/*en Name : lcrzo_winhandle_write
   Description :
     Write data in a winhandle.
     If datasize is too long, data will be written in several
     chunks (use lcrzo_winhandle_write_msg if you want data to be written
     in one step).
   Input parameter(s) :
     *pwinhandle : lcrzo_winhandle where to write
     data : data to write
     datasize : size of data to write
   Input/output parameter(s) :
   Output parameter(s) :
   Normal return values :
     LCRZO_ERR_OK : ok
*/
/*fr Nom : lcrzo_winhandle_write
   Description :
     Ecrit des donnees dans un winhandle.
     Si datasize est trop long, les donnees sont ecrites en plusieurs
     fois (employez lcrzo_winhandle_write_msg si vous desirez que les
     donnees soient ecrites en une seule fois).
   Parametre(s) d'entree :
     *pwinhandle : lcrzo_winhandle ou ecrire
     data : donnees a ecrire
     datasize : taille des donnees a ecrire
   Parametre(s) d'entree-sortie :
   Parametre(s) de sortie :
   Valeurs de retour normales :
     LCRZO_ERR_OK : ok
*/
int lcrzo_winhandle_write(lcrzo_winhandle *pwinhandle,
		     lcrzo_constdata data,
		     lcrzo_int32 datasize);

/*-------------------------------------------------------------*/
/*en Name : lcrzo_winhandle_write_msg
   Description :
     Write data in a winhandle.
   Input parameter(s) :
     *pwinhandle : lcrzo_winhandle where to write
     data : data to write
     datasize : size of data to write
   Input/output parameter(s) :
   Output parameter(s) :
   Normal return values :
     LCRZO_ERR_OK : ok
*/
/*fr Nom : lcrzo_winhandle_write_msg
   Description :
     Ecrit des donnees dans un winhandle.
   Parametre(s) d'entree :
     *pwinhandle : lcrzo_winhandle ou ecrire
     data : donnees a ecrire
     datasize : taille des donnees a ecrire
   Parametre(s) d'entree-sortie :
   Parametre(s) de sortie :
   Valeurs de retour normales :
     LCRZO_ERR_OK : ok
*/
int lcrzo_winhandle_write_msg(lcrzo_winhandle *pwinhandle,
			 lcrzo_constdata data,
			 lcrzo_int32 datasize);

/*-------------------------------------------------------------*/
/*en Name : lcrzo_winhandle_readm
   Description :
     Allocate a memory array, and initialize it with
     data read from a winhandle.
   Input parameter(s) :
     *pwinhandle : lcrzo_winhandle where to read
     *pmaxwaitingtime : maximum waiting time (can be a lcrzo_time,
                        LCRZO_WAIT_NODELAY or LCRZO_WAIT_INFINITE)
   Input/output parameter(s) :
   Output parameter(s) :
     *pdataout : pointer which will be malloced (so, the
                 memory will have to be freed by the
                 user with 'free(*pdataout)').
                 The allocated memory will be set with read data
     *pdataoutsize : reached size of *pdataout
   Normal return values :
     LCRZO_ERR_OK : ok
     LCRZO_ERR_OKTEMPDATAEND : the function received nothing
                               before pmaxwaitingtime, so it 
			       exited without reading data
*/
/*fr Nom : lcrzo_winhandle_readm
   Description :
     Alloue une zone de memoire et l'initialise avec
     des donnees lues depuis un winhandle.
   Parametre(s) d'entree :
     *pwinhandle : lcrzo_winhandle ou lire
     *pmaxwaitingtime : temps maximum d'attente (peut etre un
                        lcrzo_time, LCRZO_WAIT_NODELAY ou
			LCRZO_WAIT_INFINITE)
   Parametre(s) d'entree-sortie :
   Parametre(s) de sortie :
     *pdataout : pointeur qui sera alloue (la memoire
                 devra etre liberee par l'utilisateur 
                 avec 'free(*pdataout)').
                 Cette memoire allouee recevra les donnees lues
     *pdataoutsize : taille atteinte par *pdataout
   Valeurs de retour normales :
     LCRZO_ERR_OK : ok
     LCRZO_ERR_OKTEMPDATAEND : la fonction n'a pas recu de donnees
                               avant pmaxwaitingtime, donc on 
                               retourne sans donnees.
*/

/*-------------------------------------------------------------*/
int lcrzo_winhandle_readm(lcrzo_winhandle *pwinhandle,
		     lcrzo_time *pmaxwaitingtime, 
		     lcrzo_data *pdataout,
		     lcrzo_int32 *pdataoutsize);

/*en Name : lcrzo_winhandle_readm_fixed
   Description :
     Allocate a memory array, and initialize it with
     data of fixed size read from a winhandle.
   Input parameter(s) :
     *pwinhandle : lcrzo_winhandle where to read
     *pmaxwaitingtime : maximum waiting time (can be a lcrzo_time,
                        LCRZO_WAIT_NODELAY or LCRZO_WAIT_INFINITE)
     datasizetoread : size to read
   Input/output parameter(s) :
   Output parameter(s) :
     *pdataout : pointer which will be malloced (so, the
                 memory will have to be freed by the
                 user with 'free(*pdataout)').
                 The allocated memory will be set with read data
   Normal return values :
     LCRZO_ERR_OK : ok
     LCRZO_ERR_OKTEMPDATAEND : the function received nothing
                               (or no sufficient data) 
                               before pmaxwaitingtime, so it 
			       exited without reading data
*/
/*fr Nom : lcrzo_winhandle_readm_fixed
   Description :
     Alloue une zone de memoire et l'initialise avec
     des donnees de taille constante lues depuis un winhandle.
   Parametre(s) d'entree :
     *pwinhandle : lcrzo_winhandle ou lire
     *pmaxwaitingtime : temps maximum d'attente (peut etre un
                        lcrzo_time, LCRZO_WAIT_NODELAY ou
			LCRZO_WAIT_INFINITE)
     datasizetoread : taille des donnees a lire
   Parametre(s) d'entree-sortie :
   Parametre(s) de sortie :
     *pdataout : pointeur qui sera alloue (la memoire
                 devra etre liberee par l'utilisateur 
                 avec 'free(*pdataout)').
                 Cette memoire allouee recevra les donnees lues
   Valeurs de retour normales :
     LCRZO_ERR_OK : ok
     LCRZO_ERR_OKTEMPDATAEND : la fonction n'a pas recu de donnees
                               (ou pas assez de donnees)
                               avant pmaxwaitingtime, donc on 
                               retourne sans donnees.
*/
int lcrzo_winhandle_readm_fixed(lcrzo_winhandle *pwinhandle,
			   lcrzo_time *pmaxwaitingtime, 
			   lcrzo_int32 datasizetoread,
			   lcrzo_data *pdataout);

/*-------------------------------------------------------------*/
/*en Name : lcrzo_winhandle_readm_line
   Description :
     Allocate a memory array, and initialize it with
     data read from a winhandle. We stop at first '\r' or '\n' (which
     is not stored in data).
   Input parameter(s) :
     *pwinhandle : lcrzo_winhandle where to read
     *pmaxwaitingtime : maximum waiting time (can be a lcrzo_time,
                        LCRZO_WAIT_NODELAY or LCRZO_WAIT_INFINITE)
   Input/output parameter(s) :
   Output parameter(s) :
     *pdataout : pointer which will be malloced (so, the
                 memory will have to be freed by the
                 user with 'free(*pdataout)').
                 The allocated memory will be set with read data
     *pdataoutsize : reached size of *pdataout
   Normal return values :
     LCRZO_ERR_OK : ok
     LCRZO_ERR_OKTEMPDATAEND : the function received nothing
                               (or data containing no end of line)
                               before pmaxwaitingtime, so it 
			       exited without reading data
*/
/*fr Nom : lcrzo_winhandle_readm_line
   Description :
     Alloue une zone de memoire et l'initialise avec
     des donnees lues depuis un winhandle. On s'arrete de lire
     au premier '\r' ou '\n' (qui n'est pas stocke dans
     *pdataout).
   Parametre(s) d'entree :
     *pwinhandle : lcrzo_winhandle ou lire
     *pmaxwaitingtime : temps maximum d'attente (peut etre un
                        lcrzo_time, LCRZO_WAIT_NODELAY ou
			LCRZO_WAIT_INFINITE)
   Parametre(s) d'entree-sortie :
   Parametre(s) de sortie :
     *pdataout : pointeur qui sera alloue (la memoire
                 devra etre liberee par l'utilisateur 
                 avec 'free(*pdataout)').
                 Cette memoire allouee recevra les donnees lues
     *pdataoutsize : taille atteinte par *pdataout
   Valeurs de retour normales :
     LCRZO_ERR_OK : ok
     LCRZO_ERR_OKTEMPDATAEND : la fonction n'a pas recu de donnees
                               (ou des donnes de ccontenant pas de
                               saut de ligne) avant pmaxwaitingtime,
                               donc on retourne sans donnees.
*/
int lcrzo_winhandle_readm_line(lcrzo_winhandle *pwinhandle,
			  lcrzo_time *pmaxwaitingtime, 
			  lcrzo_data *pdataout,
			  lcrzo_int32 *pdataoutsize);



